@@ -27,9 +27,18 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 typedef struct NoiseEstimator NoiseEstimator;
 
-NoiseEstimator *noise_estimation_initialize(uint32_t fft_size,
-                                            NoiseProfile *noise_profile);
-void noise_estimation_free(NoiseEstimator *self);
-bool noise_estimation_run(NoiseEstimator *self, float *signal_spectrum);
+typedef enum NoiseEstimatorType {
+  OFF = 0,
+  ROLLING_MEAN = 1,
+  MEDIAN = 2,
+  MAX = 3,
+} NoiseEstimatorType;
 
-#endif
\ No newline at end of file
+NoiseEstimator* noise_estimation_initialize(uint32_t fft_size,
+                                            NoiseProfile* noise_profile);
+void noise_estimation_free(NoiseEstimator* self);
+bool noise_estimation_run(NoiseEstimator* self,
+                          NoiseEstimatorType noise_estimator_type,
+                          float* signal_spectrum);
+
+#endif
