@@ -21,16 +21,17 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 #ifndef SPECTRAL_WHITENER_H
 #define SPECTRAL_WHITENER_H
 
-#include <stdbool.h>
 #include <stdint.h>
 
 typedef struct SpectralWhitening SpectralWhitening;
 
-SpectralWhitening *spectral_whitening_initialize(uint32_t fft_size,
-                                                 uint32_t sample_rate,
-                                                 uint32_t hop);
-void spectral_whitening_free(SpectralWhitening *self);
-bool spectral_whitening_run(SpectralWhitening *self, float whitening_factor,
-                            float *fft_spectrum);
+SpectralWhitening* spectral_whitening_initialize(uint32_t fft_size);
 
-#endif
\ No newline at end of file
+void spectral_whitening_free(SpectralWhitening* self);
+
+void spectral_whitening_get_weights(SpectralWhitening* self,
+                                    float whitening_factor,
+                                    const float* noise_profile,
+                                    float* weights_out);
+
+#endif
